@@ -37,8 +37,7 @@
 #define GSETTINGS_KEY_POPUP_LOCATION "popup-location"
 #define GSETTINGS_KEY_MONITOR_NUMBER "monitor-number"
 #define GSETTINGS_KEY_USE_ACTIVE_MONITOR "use-active-monitor"
-
-#define NOTIFICATION_UI_FILE "mate-notification-properties.ui"
+#define GSETTINGS_KEY_DO_NOT_DISTURB "do-not-disturb"
 
 typedef struct {
 	GSettings* gsettings;
@@ -49,6 +48,7 @@ typedef struct {
 	GtkWidget* theme_combo;
 	GtkWidget* preview_button;
 	GtkWidget* active_checkbox;
+	GtkWidget* dnd_checkbox;
     GtkWidget* monitor_label;
 
 	NotifyNotification* preview;
@@ -105,16 +105,16 @@ static void notification_properties_monitor_changed(GtkComboBox* widget, Notific
 {
 	gint monitor;
 	GtkTreeIter iter;
-	
+
 	GtkTreeModel *model = gtk_combo_box_get_model(GTK_COMBO_BOX(dialog->monitor_combo));
-	
+
 	if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(dialog->monitor_combo), &iter))
 	{
 		return;
 	}
-	
+
 	gtk_tree_model_get(model, &iter, NOTIFY_MONITOR_NUMBER, &monitor, -1);
-	
+
 	g_settings_set_int(dialog->gsettings, GSETTINGS_KEY_MONITOR_NUMBER, monitor);
 }
 
@@ -129,11 +129,11 @@ static void notification_properties_monitor_notify(GSettings *settings, gchar *k
 	model = gtk_combo_box_get_model(GTK_COMBO_BOX(dialog->monitor_combo));
 
 	monitor_number = g_settings_get_int(dialog->gsettings, GSETTINGS_KEY_MONITOR_NUMBER);
-	
+
 	for (valid = gtk_tree_model_get_iter_first(model, &iter); valid; valid = gtk_tree_model_iter_next(model, &iter))
 	{
 		gtk_tree_model_get(model, &iter, NOTIFY_MONITOR_NUMBER, &monitor_number_at_iter, -1);
-		
+
 		if (monitor_number_at_iter == monitor_number)
 		{
 			gtk_combo_box_set_active_iter(GTK_COMBO_BOX(dialog->monitor_combo), &iter);
@@ -207,15 +207,15 @@ static void notification_properties_dialog_setup_monitors(NotificationAppletDial
 	// TODO: add support for multiple displays.
 	display = gdk_display_get_default();
 	g_assert(display != NULL);
-	
+
 	// Assumes the user has only one screen.
 	// TODO: add support for mulitple screens.
 	screen = gdk_display_get_default_screen(display);
 	g_assert(screen != NULL);
-	
+
 	num_monitors = gdk_display_get_n_monitors(display);
 	g_assert(num_monitors >= 1);
-	
+
 	store = gtk_list_store_new(N_COLUMNS_MONITOR, G_TYPE_INT);
 
     gint i;
@@ -224,21 +224,21 @@ static void notification_properties_dialog_setup_monitors(NotificationAppletDial
         gtk_list_store_append(store, &iter);
 		gtk_list_store_set(store, &iter, NOTIFY_MONITOR_NUMBER, i, -1);
 	}
-	
+
 	gtk_combo_box_set_model(GTK_COMBO_BOX (dialog->monitor_combo), GTK_TREE_MODEL (store));
-	
+
 	g_signal_connect(dialog->gsettings, "changed::" GSETTINGS_KEY_MONITOR_NUMBER, G_CALLBACK (notification_properties_monitor_notify), dialog);
 	cur_monitor_number = g_settings_get_int(dialog->gsettings, GSETTINGS_KEY_MONITOR_NUMBER);
 
 	for (valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL (store), &iter); valid; valid = gtk_tree_model_iter_next(GTK_TREE_MODEL (store), &iter))
 	{
 		gtk_tree_model_get(GTK_TREE_MODEL (store), &iter, NOTIFY_MONITOR_NUMBER, &cur_monitor_number_at_iter, -1);
-		
+
 		if (cur_monitor_number_at_iter == cur_monitor_number)
 		{
 			gtk_combo_box_set_active_iter(GTK_COMBO_BOX(dialog->monitor_combo), &iter);
 			break;
-		}				
+		}
 	}
 
 	g_object_unref(store);
@@ -434,6 +434,38 @@ static void notification_properties_checkbox_notify(GSettings *settings, gchar *
 	}
 }
 
+static void notification_properties_dnd_toggled(GtkWidget* widget, NotificationAppletDialog* dialog)
+{
+	gboolean is_active;
+
+	is_active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (widget));
+
+	// This was called as a result of notification_properties_dnd_notify being called.
+	// Stop here instead of doing redundant work.
+	if (is_active == g_settings_get_boolean(dialog->gsettings, GSETTINGS_KEY_DO_NOT_DISTURB))
+	{
+		return;
+	}
+
+	g_settings_set_boolean(dialog->gsettings, GSETTINGS_KEY_DO_NOT_DISTURB, is_active);
+}
+
+static void notification_properties_dnd_notify(GSettings *settings, gchar *key, NotificationAppletDialog* dialog)
+{
+	gboolean is_set;
+
+	is_set = g_settings_get_boolean(settings, key);
+
+	// This was called as a result of notification_properties_dnd_toggled being called.
+	// Stop here instead of doing redundant work.
+	if(is_set == gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (dialog->dnd_checkbox)))
+	{
+		return;
+	}
+
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (dialog->dnd_checkbox), is_set);
+}
+
 static void show_message(NotificationAppletDialog* dialog, const gchar* message)
 {
 	GtkWidget* d = gtk_message_dialog_new(GTK_WINDOW(dialog->dialog), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "%s", message);
@@ -505,25 +537,14 @@ static void notification_properties_dialog_destroyed(GtkWidget* widget, Notifica
 
 static gboolean notification_properties_dialog_init(NotificationAppletDialog* dialog)
 {
-	const char* ui_file;
-
-	if (g_file_test(NOTIFICATION_UI_FILE, G_FILE_TEST_EXISTS))
-	{
-		ui_file = NOTIFICATION_UI_FILE;
-	}
-	else
-	{
-		ui_file = NOTIFICATION_UIDIR "/" NOTIFICATION_UI_FILE;
-	}
-
 	GtkBuilder* builder = gtk_builder_new();
 	GError* error = NULL;
 
-	gtk_builder_add_from_file(builder, ui_file, &error);
+	gtk_builder_add_from_resource (builder, "/org/mate/notifications/properties/mate-notification-properties.ui", &error);
 
 	if (error != NULL)
 	{
-		g_warning(_("Could not load user interface file: %s"), error->message);
+		g_warning(_("Could not load user interface: %s"), error->message);
 		g_error_free(error);
 		return FALSE;
 	}
@@ -536,16 +557,19 @@ static gboolean notification_properties_dialog_init(NotificationAppletDialog* di
 
 	dialog->monitor_combo = GTK_WIDGET(gtk_builder_get_object(builder, "monitor_combo"));
 	g_assert(dialog->monitor_combo != NULL);
-	
+
 	dialog->theme_combo = GTK_WIDGET(gtk_builder_get_object(builder, "theme_combo"));
 	g_assert(dialog->theme_combo != NULL);
-	
+
 	dialog->active_checkbox = GTK_WIDGET(gtk_builder_get_object(builder, "use_active_check"));
-	g_assert(dialog->active_checkbox != NULL);	
+	g_assert(dialog->active_checkbox != NULL);
+
+	dialog->dnd_checkbox = GTK_WIDGET(gtk_builder_get_object(builder, "do_not_disturb_check"));
+	g_assert(dialog->dnd_checkbox != NULL);
 
     dialog->monitor_label = GTK_WIDGET(gtk_builder_get_object(builder, "monitor_label"));
     g_assert(dialog->monitor_label != NULL);
-	
+
 	g_object_unref(builder);
 
 	dialog->gsettings = g_settings_new (GSETTINGS_SCHEMA);
@@ -556,6 +580,9 @@ static gboolean notification_properties_dialog_init(NotificationAppletDialog* di
 	g_signal_connect(dialog->gsettings, "changed::" GSETTINGS_KEY_USE_ACTIVE_MONITOR, G_CALLBACK (notification_properties_checkbox_notify), dialog);
 	g_signal_connect(dialog->active_checkbox, "toggled", G_CALLBACK(notification_properties_checkbox_toggled), dialog);
 
+	g_signal_connect(dialog->gsettings, "changed::" GSETTINGS_KEY_DO_NOT_DISTURB, G_CALLBACK (notification_properties_dnd_notify), dialog);
+	g_signal_connect(dialog->dnd_checkbox, "toggled", G_CALLBACK(notification_properties_dnd_toggled), dialog);
+
 	notification_properties_dialog_setup_themes(dialog);
 	notification_properties_dialog_setup_positions(dialog);
 	notification_properties_dialog_setup_monitors(dialog);
@@ -572,6 +599,8 @@ static gboolean notification_properties_dialog_init(NotificationAppletDialog* di
         gtk_widget_set_sensitive(dialog->monitor_label, TRUE);
 	}
 
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (dialog->dnd_checkbox), g_settings_get_boolean(dialog->gsettings, GSETTINGS_KEY_DO_NOT_DISTURB));
+
 	gtk_widget_show_all(dialog->dialog);
 
 	dialog->preview = NULL;
